#!/usr/bin/env node
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var net = require('net');
var buffer = require('buffer');

const types = new Map();
function setType(fullName, cons) {
    types.set(fullName, cons);
}
var _Symbol = {
    reflection: Symbol("reflection"),
};

function padWithZeros(i, length) {
    let str = i.toString(10);
    while (str.length < length) {
        str = "0" + str;
    }
    return str;
}
function offsetToString(offset) {
    const isMinus = offset < 0;
    offset = Math.abs(offset);
    const hours = ~~(offset / 3600000);
    const minutes = (offset % 3600000) / 60000;
    return (isMinus ? "-" : "+") +
        padWithZeros(hours, 2) + ":" +
        padWithZeros(minutes, 2);
}
function toHalfUTCString(date, half) {
    const str = date.toISOString();
    return half === "first"
        ? str.substring(0, str.indexOf("T"))
        : str.substring(str.indexOf("T") + 1, str.length - 1);
}
function toISOString(d, utc) {
    if (utc) {
        return d.toISOString();
    }
    else {
        const printOffset = d.kind == null ? true : d.kind === 2            ;
        return padWithZeros(d.getFullYear(), 4) + "-" +
            padWithZeros(d.getMonth() + 1, 2) + "-" +
            padWithZeros(d.getDate(), 2) + "T" +
            padWithZeros(d.getHours(), 2) + ":" +
            padWithZeros(d.getMinutes(), 2) + ":" +
            padWithZeros(d.getSeconds(), 2) + "." +
            padWithZeros(d.getMilliseconds(), 3) +
            (printOffset ? offsetToString(d.getTimezoneOffset() * -60000) : "");
    }
}
function toISOStringWithOffset(dateWithOffset, offset) {
    const str = dateWithOffset.toISOString();
    return str.substring(0, str.length - 1) + offsetToString(offset);
}
function toStringWithCustomFormat(date, format, utc) {
    return format.replace(/(\w)\1*/g, (match) => {
        let rep = match;
        switch (match.substring(0, 1)) {
            case "y":
                const y = utc ? date.getUTCFullYear() : date.getFullYear();
                rep = match.length < 4 ? y % 100 : y;
                break;
            case "M":
                rep = (utc ? date.getUTCMonth() : date.getMonth()) + 1;
                break;
            case "d":
                rep = utc ? date.getUTCDate() : date.getDate();
                break;
            case "H":
                rep = utc ? date.getUTCHours() : date.getHours();
                break;
            case "h":
                const h = utc ? date.getUTCHours() : date.getHours();
                rep = h > 12 ? h % 12 : h;
                break;
            case "m":
                rep = utc ? date.getUTCMinutes() : date.getMinutes();
                break;
            case "s":
                rep = utc ? date.getUTCSeconds() : date.getSeconds();
                break;
        }
        if (rep !== match && rep < 10 && match.length > 1) {
            rep = "0" + rep;
        }
        return rep;
    });
}
function toStringWithOffset(date, format) {
    const d = new Date(date.getTime() + date.offset);
    if (!format) {
        return d.toISOString().replace(/\.\d+/, "").replace(/[A-Z]|\.\d+/g, " ") + offsetToString(date.offset);
    }
    else if (format.length === 1) {
        switch (format) {
            case "D":
            case "d": return toHalfUTCString(d, "first");
            case "T":
            case "t": return toHalfUTCString(d, "second");
            case "O":
            case "o": return toISOStringWithOffset(d, date.offset);
            default: throw new Error("Unrecognized Date print format");
        }
    }
    else {
        return toStringWithCustomFormat(d, format, true);
    }
}
function toStringWithKind(date, format) {
    const utc = date.kind === 1          ;
    if (!format) {
        return utc ? date.toUTCString() : date.toLocaleString();
    }
    else if (format.length === 1) {
        switch (format) {
            case "D":
            case "d":
                return utc ? toHalfUTCString(date, "first") : date.toLocaleDateString();
            case "T":
            case "t":
                return utc ? toHalfUTCString(date, "second") : date.toLocaleTimeString();
            case "O":
            case "o":
                return toISOString(date, utc);
            default:
                throw new Error("Unrecognized Date print format");
        }
    }
    else {
        return toStringWithCustomFormat(date, format, utc);
    }
}
function toString(date, format) {
    return date.offset != null
        ? toStringWithOffset(date, format)
        : toStringWithKind(date, format);
}
function compare(x, y) {
    const xtime = x.getTime();
    const ytime = y.getTime();
    return xtime === ytime ? 0 : (xtime < ytime ? -1 : 1);
}

class NonDeclaredType {
    constructor(kind, definition, generics) {
        this.kind = kind;
        this.definition = definition;
        this.generics = generics;
    }
    Equals(other) {
        if (this.kind === other.kind && this.definition === other.definition) {
            return typeof this.generics === "object"
                ? equalsRecords(this.generics, other.generics)
                : this.generics === other.generics;
        }
        return false;
    }
}
const Any = new NonDeclaredType("Any");
function GenericParam(definition) {
    return new NonDeclaredType("GenericParam", definition);
}
function makeGeneric(typeDef, genArgs) {
    return new NonDeclaredType("GenericType", typeDef, genArgs);
}
function hasInterface(obj, interfaceName) {
    if (interfaceName === "System.Collections.Generic.IEnumerable") {
        return typeof obj[Symbol.iterator] === "function";
    }
    else if (typeof obj[_Symbol.reflection] === "function") {
        const interfaces = obj[_Symbol.reflection]().interfaces;
        return Array.isArray(interfaces) && interfaces.indexOf(interfaceName) > -1;
    }
    return false;
}
function getPropertyNames(obj) {
    if (obj == null) {
        return [];
    }
    const propertyMap = typeof obj[_Symbol.reflection] === "function" ? obj[_Symbol.reflection]().properties || [] : obj;
    return Object.getOwnPropertyNames(propertyMap);
}
function toString$1(obj, quoteStrings = false) {
    function isObject(x) {
        return x !== null && typeof x === "object" && !(x instanceof Number)
            && !(x instanceof String) && !(x instanceof Boolean);
    }
    if (obj == null || typeof obj === "number") {
        return String(obj);
    }
    if (typeof obj === "string") {
        return quoteStrings ? JSON.stringify(obj) : obj;
    }
    if (obj instanceof Date) {
        return toString(obj);
    }
    if (typeof obj.ToString === "function") {
        return obj.ToString();
    }
    if (hasInterface(obj, "FSharpUnion")) {
        const info = obj[_Symbol.reflection]();
        const uci = info.cases[obj.tag];
        switch (uci.length) {
            case 1:
                return uci[0];
            case 2:
                return uci[0] + " (" + toString$1(obj.data, true) + ")";
            default:
                return uci[0] + " (" + obj.data.map((x) => toString$1(x, true)).join(",") + ")";
        }
    }
    try {
        return JSON.stringify(obj, (k, v) => {
            return v && v[Symbol.iterator] && !Array.isArray(v) && isObject(v) ? Array.from(v)
                : v && typeof v.ToString === "function" ? toString$1(v) : v;
        });
    }
    catch (err) {
        return "{" + Object.getOwnPropertyNames(obj).map((k) => k + ": " + String(obj[k])).join(", ") + "}";
    }
}
function hash(x) {
    if (typeof x === typeof 1) {
        return x * 2654435761 | 0;
    }
    if (x != null && typeof x.GetHashCode === "function") {
        return x.GetHashCode();
    }
    else {
        const s = toString$1(x);
        let h = 5381;
        let i = 0;
        const len = s.length;
        while (i < len) {
            h = (h * 33) ^ s.charCodeAt(i++);
        }
        return h;
    }
}
function equals$1(x, y) {
    if (x === y) {
        return true;
    }
    else if (x == null) {
        return y == null;
    }
    else if (y == null) {
        return false;
    }
    else if (typeof x !== "object" || typeof y !== "object") {
        return x === y;
    }
    else if (typeof x.Equals === "function") {
        return x.Equals(y);
    }
    else if (typeof y.Equals === "function") {
        return y.Equals(x);
    }
    else if (Object.getPrototypeOf(x) !== Object.getPrototypeOf(y)) {
        return false;
    }
    else if (Array.isArray(x)) {
        if (x.length !== y.length) {
            return false;
        }
        for (let i = 0; i < x.length; i++) {
            if (!equals$1(x[i], y[i])) {
                return false;
            }
        }
        return true;
    }
    else if (ArrayBuffer.isView(x)) {
        if (x.byteLength !== y.byteLength) {
            return false;
        }
        const dv1 = new DataView(x.buffer);
        const dv2 = new DataView(y.buffer);
        for (let i = 0; i < x.byteLength; i++) {
            if (dv1.getUint8(i) !== dv2.getUint8(i)) {
                return false;
            }
        }
        return true;
    }
    else if (x instanceof Date) {
        return x.getTime() === y.getTime();
    }
    else {
        return false;
    }
}
function comparePrimitives(x, y) {
    return x === y ? 0 : (x < y ? -1 : 1);
}
function compare$1(x, y) {
    if (x === y) {
        return 0;
    }
    else if (x == null) {
        return y == null ? 0 : -1;
    }
    else if (y == null) {
        return 1;
    }
    else if (typeof x !== "object" || typeof y !== "object") {
        return x === y ? 0 : (x < y ? -1 : 1);
    }
    else if (typeof x.CompareTo === "function") {
        return x.CompareTo(y);
    }
    else if (typeof y.CompareTo === "function") {
        return y.CompareTo(x) * -1;
    }
    else if (Object.getPrototypeOf(x) !== Object.getPrototypeOf(y)) {
        return -1;
    }
    else if (Array.isArray(x)) {
        if (x.length !== y.length) {
            return x.length < y.length ? -1 : 1;
        }
        for (let i = 0, j = 0; i < x.length; i++) {
            j = compare$1(x[i], y[i]);
            if (j !== 0) {
                return j;
            }
        }
        return 0;
    }
    else if (ArrayBuffer.isView(x)) {
        if (x.byteLength !== y.byteLength) {
            return x.byteLength < y.byteLength ? -1 : 1;
        }
        const dv1 = new DataView(x.buffer);
        const dv2 = new DataView(y.buffer);
        for (let i = 0, b1 = 0, b2 = 0; i < x.byteLength; i++) {
            b1 = dv1.getUint8(i), b2 = dv2.getUint8(i);
            if (b1 < b2) {
                return -1;
            }
            if (b1 > b2) {
                return 1;
            }
        }
        return 0;
    }
    else if (x instanceof Date) {
        return compare(x, y);
    }
    else if (typeof x === "object") {
        const xhash = hash(x);
        const yhash = hash(y);
        if (xhash === yhash) {
            return equals$1(x, y) ? 0 : -1;
        }
        else {
            return xhash < yhash ? -1 : 1;
        }
    }
    else {
        return x < y ? -1 : 1;
    }
}
function equalsRecords(x, y) {
    if (x === y) {
        return true;
    }
    else {
        const keys = getPropertyNames(x);
        for (const key of keys) {
            if (!equals$1(x[key], y[key])) {
                return false;
            }
        }
        return true;
    }
}
function equalsUnions(x, y) {
    return x === y || (x.tag === y.tag && equals$1(x.data, y.data));
}
function compareUnions(x, y) {
    if (x === y) {
        return 0;
    }
    else {
        const res = x.tag < y.tag ? -1 : (x.tag > y.tag ? 1 : 0);
        return res !== 0 ? res : compare$1(x.data, y.data);
    }
}

function identity(value) {
    return value;
}
var encodeNull = null;
function encodeObject(values) {
    const obj = {};
    while (values.head !== undefined) {
        const pair = values.head;
        obj[pair[0]] = pair[1];
        values = values.tail;
    }
    return obj;
}
var stringify = JSON.stringify;
function encodeList(values) {
    let array = [];
    while (values.head !== undefined) {
        array = array.concat(values.head);
        values = values.tail;
    }
    return array;
}

function ofArray(args, base) {
    let acc = base || new List();
    for (let i = args.length - 1; i >= 0; i--) {
        acc = new List(args[i], acc);
    }
    return acc;
}
class List {
    constructor(head, tail) {
        this.head = head;
        this.tail = tail;
    }
    ToString() {
        return "[" + Array.from(this).map((x) => toString$1(x)).join("; ") + "]";
    }
    Equals(other) {
        if (this === other) {
            return true;
        }
        else {
            let cur1 = this;
            let cur2 = other;
            while (equals$1(cur1.head, cur2.head)) {
                cur1 = cur1.tail;
                cur2 = cur2.tail;
                if (cur1 == null) {
                    return cur2 == null;
                }
            }
            return false;
        }
    }
    CompareTo(other) {
        if (this === other) {
            return 0;
        }
        else {
            let cur1 = this;
            let cur2 = other;
            let res = compare$1(cur1.head, cur2.head);
            while (res === 0) {
                cur1 = cur1.tail;
                cur2 = cur2.tail;
                if (cur1 == null) {
                    return cur2 == null ? 0 : -1;
                }
                res = compare$1(cur1.head, cur2.head);
            }
            return res;
        }
    }
    get length() {
        let cur = this;
        let acc = 0;
        while (cur.tail != null) {
            cur = cur.tail;
            acc++;
        }
        return acc;
    }
    [Symbol.iterator]() {
        let cur = this;
        return {
            next: () => {
                const tmp = cur;
                cur = cur.tail;
                return { done: tmp.tail == null, value: tmp.head };
            },
        };
    }
    [_Symbol.reflection]() {
        return {
            type: "Microsoft.FSharp.Collections.FSharpList",
            interfaces: ["System.IEquatable", "System.IComparable"],
        };
    }
}

class Some {
    constructor(value) {
        this.value = value;
    }
    ToString() {
        return toString$1(this.value);
    }
    Equals(other) {
        if (other == null) {
            return false;
        }
        else {
            return equals$1(this.value, other instanceof Some
                ? other.value : other);
        }
    }
    CompareTo(other) {
        if (other == null) {
            return 1;
        }
        else {
            return compare$1(this.value, other instanceof Some
                ? other.value : other);
        }
    }
}
function getValue(x, acceptNull) {
    if (x == null) {
        if (!acceptNull) {
            throw new Error("Option has no value");
        }
        return null;
    }
    else {
        return x instanceof Some ? x.value : x;
    }
}
function defaultArg(arg, defaultValue, f) {
    return arg == null ? defaultValue : (f != null ? f(getValue(arg)) : getValue(arg));
}

function fold(f, acc, xs) {
    if (Array.isArray(xs) || ArrayBuffer.isView(xs)) {
        return xs.reduce(f, acc);
    }
    else {
        let cur;
        for (let i = 0, iter = xs[Symbol.iterator]();; i++) {
            cur = iter.next();
            if (cur.done) {
                break;
            }
            acc = f(acc, cur.value, i);
        }
        return acc;
    }
}

function CurriedLambda(f, expectedArgsLength) {
    if (f.curried === true) {
        return f;
    }
    const curriedFn = (...args) => {
        const args2 = args.map((x) => typeof x === "function" ? CurriedLambda(x) : x);
        const actualArgsLength = Math.max(args2.length, 1);
        expectedArgsLength = Math.max(expectedArgsLength || f.length, 1);
        if (actualArgsLength >= expectedArgsLength) {
            const restArgs = args2.splice(expectedArgsLength);
            const res = f(...args2);
            if (typeof res === "function") {
                const newLambda = CurriedLambda(res);
                return restArgs.length === 0 ? newLambda : newLambda(...restArgs);
            }
            else {
                return res;
            }
        }
        else {
            return CurriedLambda((...args3) => {
                return f(...args2.concat(args3));
            }, expectedArgsLength - actualArgsLength);
        }
    };
    curriedFn.curried = true;
    return curriedFn;
}

class Value {
    constructor(tag) {
        this.tag = tag | 0;
    }

    [_Symbol.reflection]() {
        return {
            type: "Thoth.Json.Encode.Value",
            interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
            cases: [["Value"]]
        };
    }

    Equals(other) {
        return this.tag === other.tag;
    }

    CompareTo(other) {
        return comparePrimitives(this.tag, other.tag);
    }

}
setType("Thoth.Json.Encode.Value", Value);

const FFI = function (__exports) {
    const identity$$1 = __exports.identity = identity;
    const encodeNull$$1 = __exports.encodeNull = encodeNull;
    const encodeObject$$1 = __exports.encodeObject = encodeObject;
    const stringify$$1 = __exports.stringify = stringify;
    const encodeList$$1 = __exports.encodeList = encodeList;
    return __exports;
}({});

function string(value) {
    return FFI.identity(value);
}
const nil = FFI.encodeNull;
function object(values) {
    return FFI.encodeObject(values);
}
function array(values) {
    return FFI.identity(values);
}
function encode(space, value) {
    return FFI.stringify(value, null, space);
}

function append$1(xs, ys) {
    return fold((acc, x) => new List(x, acc), ys, reverse$1(xs));
}
function reverse$1(xs) {
    return fold((acc, x) => new List(x, acc), new List(), xs);
}

function join(delimiter, xs) {
    let xs2 = typeof xs === "string" ? [xs] : xs;
    const len = arguments.length;
    if (len > 2) {
        xs2 = Array(len - 1);
        for (let key = 1; key < len; key++) {
            xs2[key - 1] = arguments[key];
        }
    }
    else if (!Array.isArray(xs2)) {
        xs2 = Array.from(xs2);
    }
    return xs2.map((x) => toString$1(x)).join(delimiter);
}

class Result {
    constructor(tag, data) {
        this.tag = tag | 0;
        this.data = data;
    }
    Equals(other) {
        return equalsUnions(this, other);
    }
    CompareTo(other) {
        return compareUnions(this, other);
    }
    [_Symbol.reflection]() {
        return {
            type: "Microsoft.FSharp.Core.FSharpResult",
            interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
            cases: [["Ok", GenericParam("T")], ["Error", GenericParam("TError")]],
        };
    }
}
function mapError(f, result) {
    return result.tag === 1 ? new Result(1, f(result.data)) : result;
}

class DecoderError {
    constructor(tag, data) {
        this.tag = tag | 0;
        this.data = data;
    }

    [_Symbol.reflection]() {
        return {
            type: "Thoth.Json.Decode.DecoderError",
            interfaces: ["FSharpUnion", "System.IEquatable"],
            cases: [["BadPrimitive", "string", Any], ["BadPrimitiveExtra", "string", Any, "string"], ["BadField", "string", Any], ["BadPath", "string", Any, "string"], ["TooSmallArray", "string", Any], ["FailMessage", "string"], ["BadOneOf", makeGeneric(List, {
                T: "string"
            })]]
        };
    }

    Equals(other) {
        return this === other || this.tag === other.tag && equals$1(this.data, other.data);
    }

}
setType("Thoth.Json.Decode.DecoderError", DecoderError);

function genericMsg(msg, value, newLine) {
    try {
        return "Expecting " + msg + " but instead got:" + (newLine ? "\n" : " ") + (JSON.stringify(value, null, 4) + "");
    } catch (matchValue) {
        return "Expecting " + msg + " but decoder failed. Couldn't report given value due to circular structure." + (newLine ? "\n" : " ");
    }
}

function errorToString(_arg1) {
    switch (_arg1.tag) {
        case 1:
            return genericMsg(_arg1.data[0], _arg1.data[1], false) + "\nReason: " + _arg1.data[2];

        case 2:
            return genericMsg(_arg1.data[0], _arg1.data[1], true);

        case 3:
            return genericMsg(_arg1.data[0], _arg1.data[1], true) + ("\nNode `" + _arg1.data[2] + "` is unkown.");

        case 4:
            return "Expecting " + _arg1.data[0] + ".\n" + (JSON.stringify(_arg1.data[1], null, 4) + "");

        case 6:
            return "I run into the following problems:\n\n" + join("\n", _arg1.data);

        case 5:
            return "I run into a `fail` decoder: " + _arg1.data;

        default:
            return genericMsg(_arg1.data[0], _arg1.data[1], false);
    }
}

function unwrap(decoder, value) {
    const matchValue = decoder(value);

    if (matchValue.tag === 1) {
        throw new Error(errorToString(matchValue.data));
    } else {
        return matchValue.data;
    }
}
function decodeValue(decoder, value) {
    try {
        const matchValue = decoder(value);

        if (matchValue.tag === 1) {
            return new Result(1, errorToString(matchValue.data));
        } else {
            return new Result(0, matchValue.data);
        }
    } catch (ex) {
        return new Result(1, ex.message);
    }
}
function decodeString(decoder, value) {
    try {
        const json = JSON.parse(value);
        return decodeValue(decoder, json);
    } catch (ex) {
        return new Result(1, "Given an invalid JSON: " + ex.message);
    }
}
function string$1(value) {
    if (typeof value === "string") {
        return new Result(0, value);
    } else {
        return new Result(1, new DecoderError(0, ["a string", value]));
    }
}
function field(fieldName, decoder, value) {
    const fieldValue = value[fieldName];

    if (fieldValue !== undefined) {
        return decoder(fieldValue);
    } else {
        return new Result(1, new DecoderError(2, ["an object with a field named `" + fieldName + "`", value]));
    }
}
function oneOf(decoders, value) {
    const runner = function (decoders_1, errors) {
        runner: while (true) {
            if (decoders_1.tail == null) {
                return new Result(1, new DecoderError(6, errors));
            } else {
                const matchValue = decodeValue(decoders_1.head, value);

                if (matchValue.tag === 1) {
                    decoders_1 = decoders_1.tail;
                    errors = append$1(errors, ofArray([matchValue.data]));
                    continue runner;
                } else {
                    return new Result(0, matchValue.data);
                }
            }
        }
    };

    return runner(decoders, new List());
}
function succeed(output, _arg1) {
    return new Result(0, output);
}
function fail(msg, _arg1) {
    return new Result(1, new DecoderError(5, msg));
}
function andThen(cb, decoder, value_1) {
    const matchValue = decodeValue(decoder, value_1);

    if (matchValue.tag === 0) {
        return cb(matchValue.data, value_1);
    } else {
        throw new Error(matchValue.data);
    }
}
function map$5(ctor, d1, value_1) {
    const t = unwrap(d1, value_1);
    return new Result(0, ctor(t));
}
function map2$1(ctor, d1, d2, value_1) {
    const t = unwrap(d1, value_1);
    const t2 = unwrap(d2, value_1);
    return new Result(0, ctor(t, t2));
}
function map3$1(ctor, d1, d2, d3, value_1) {
    const v1 = unwrap(d1, value_1);
    const v2 = unwrap(d2, value_1);
    const v3 = unwrap(d3, value_1);
    return new Result(0, ctor(v1, v2, v3));
}
function map4(ctor, d1, d2, d3, d4, value_1) {
    const v1 = unwrap(d1, value_1);
    const v2 = unwrap(d2, value_1);
    const v3 = unwrap(d3, value_1);
    const v4 = unwrap(d4, value_1);
    return new Result(0, ctor(v1, v2, v3, v4));
}
function map5(ctor, d1, d2, d3, d4, d5, value_1) {
    const v1 = unwrap(d1, value_1);
    const v2 = unwrap(d2, value_1);
    const v3 = unwrap(d3, value_1);
    const v4 = unwrap(d4, value_1);
    const v5 = unwrap(d5, value_1);
    return new Result(0, ctor(v1, v2, v3, v4, v5));
}

class ZedCommand {
  constructor(tag, data) {
    this.tag = tag | 0;
    this.data = data;
  }

  [_Symbol.reflection]() {
    return {
      type: "IML.Types.CommandTypes.ZedCommand",
      interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
      cases: [["Init"], ["CreateZpool", Any, Any, Any], ["ImportZpool", Any, Any, Any], ["ExportZpool", Any, Any], ["DestroyZpool", Any], ["CreateZfs", Any, Any], ["DestroyZfs", Any, Any], ["SetZpoolProp", Any, "string", "string"], ["SetZfsProp", Any, Any, "string", "string"], ["AddVdev", Any]]
    };
  }

  Equals(other) {
    return this === other || this.tag === other.tag && equals$1(this.data, other.data);
  }

  CompareTo(other) {
    return compareUnions(this, other) | 0;
  }

}
setType("IML.Types.CommandTypes.ZedCommand", ZedCommand);
const ZedCommandModule = function (__exports) {
  const encode$$1 = __exports.encode = function (x) {
    return function (x_1) {
      return object(ofArray([["ZedCommand", x_1]]));
    }(function (_arg1) {
      switch (_arg1.tag) {
        case 1:
          const state = _arg1.data[2];
          const name = _arg1.data[0];
          const guid = _arg1.data[1];
          return object(ofArray([["CreateZpool", array([string(name), string(guid), string(state)])]]));

        case 2:
          const state_1 = _arg1.data[2];
          const name_1 = _arg1.data[0];
          const guid_1 = _arg1.data[1];
          return object(ofArray([["ImportZpool", array([string(name_1), string(guid_1), string(state_1)])]]));

        case 3:
          const state_2 = _arg1.data[1];
          const guid_2 = _arg1.data[0];
          return object(ofArray([["ExportZpool", array([string(guid_2), string(state_2)])]]));

        case 4:
          const guid_3 = _arg1.data;
          return object(ofArray([["DestroyZpool", array([string(guid_3)])]]));

        case 5:
          const name_2 = _arg1.data[1];
          const guid_4 = _arg1.data[0];
          return object(ofArray([["CreateZfs", array([string(guid_4), string(name_2)])]]));

        case 6:
          const name_3 = _arg1.data[1];
          const guid_5 = _arg1.data[0];
          return object(ofArray([["DestroyZfs", array([string(guid_5), string(name_3)])]]));

        case 7:
          const guid_6 = _arg1.data[0];
          return object(ofArray([["SetZpoolProp", array([string(guid_6), string(_arg1.data[1]), string(_arg1.data[2])])]]));

        case 8:
          const name_4 = _arg1.data[1];
          const guid_7 = _arg1.data[0];
          return object(ofArray([["SetZfsProp", array([string(guid_7), string(name_4), string(_arg1.data[2]), string(_arg1.data[3])])]]));

        case 9:
          const guid_8 = _arg1.data;
          return object(ofArray([["AddVdev", array([string(guid_8)])]]));

        default:
          return string("Init");
      }
    }(x));
  };

  const decodeInit = __exports.decodeInit = CurriedLambda(CurriedLambda((() => {
    const cb = CurriedLambda(function (_arg1) {
      if (_arg1 === "Init") {
        const output = new ZedCommand(0);
        return function (arg10_) {
          return succeed(output, arg10_);
        };
      } else {
        const msg = "Expected ZedCommand.Init, got " + _arg1;
        return function (arg10__1) {
          return fail(msg, arg10__1);
        };
      }
    });
    return function (decoder, value$$1) {
      return andThen(cb, decoder, value$$1);
    };
  })())(string$1));
  const decodeCreateZPool = __exports.decodeCreateZPool = CurriedLambda((() => {
    let decoder_3;

    const ctor = function (name, guid, state) {
      return new ZedCommand(1, [name, guid, state]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    decoder_3 = function (value_6) {
      return map3$1(ctor, d1, d2, d3, value_6);
    };

    return function (value_7) {
      return field("CreateZpool", decoder_3, value_7);
    };
  })());
  const decodeImportZPool = __exports.decodeImportZPool = CurriedLambda((() => {
    let decoder_3;

    const ctor = function (name, guid, state) {
      return new ZedCommand(2, [name, guid, state]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    decoder_3 = function (value_6) {
      return map3$1(ctor, d1, d2, d3, value_6);
    };

    return function (value_7) {
      return field("ImportZpool", decoder_3, value_7);
    };
  })());
  const decodeExportZPool = __exports.decodeExportZPool = CurriedLambda((() => {
    let decoder_2;

    const ctor = function (guid, state) {
      return new ZedCommand(3, [guid, state]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    decoder_2 = function (value_4) {
      return map2$1(ctor, d1, d2, value_4);
    };

    return function (value_5) {
      return field("ExportZpool", decoder_2, value_5);
    };
  })());
  const decodeDestroyZpool = __exports.decodeDestroyZpool = CurriedLambda((() => {
    let decoder_1;

    const ctor = $var1 => {
      return new ZedCommand(4, $var1);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    decoder_1 = function (value_2) {
      return map$5(ctor, d1, value_2);
    };

    return function (value_3) {
      return field("DestroyZpool", decoder_1, value_3);
    };
  })());
  const decodeCreateZfs = __exports.decodeCreateZfs = CurriedLambda((() => {
    let decoder_2;

    const ctor = function (guid, name) {
      return new ZedCommand(5, [guid, name]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    decoder_2 = function (value_4) {
      return map2$1(ctor, d1, d2, value_4);
    };

    return function (value_5) {
      return field("CreateZfs", decoder_2, value_5);
    };
  })());
  const decodeDestroyZfs = __exports.decodeDestroyZfs = CurriedLambda((() => {
    let decoder_2;

    const ctor = function (guid, name) {
      return new ZedCommand(6, [guid, name]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    decoder_2 = function (value_4) {
      return map2$1(ctor, d1, d2, value_4);
    };

    return function (value_5) {
      return field("DestroyZfs", decoder_2, value_5);
    };
  })());
  const decodeSetZpoolProp = __exports.decodeSetZpoolProp = CurriedLambda((() => {
    let decoder_3;

    const ctor = function (guid, key, value$$1) {
      return new ZedCommand(7, [guid, key, value$$1]);
    };

    let d1;

    const decoder = function (value_1) {
      return string$1(value_1);
    };

    d1 = function (value_2) {
      return field("0", decoder, value_2);
    };

    let d2;

    const decoder_1 = function (value_3) {
      return string$1(value_3);
    };

    d2 = function (value_4) {
      return field("1", decoder_1, value_4);
    };

    let d3;

    const decoder_2 = function (value_5) {
      return string$1(value_5);
    };

    d3 = function (value_6) {
      return field("2", decoder_2, value_6);
    };

    decoder_3 = function (value_7) {
      return map3$1(ctor, d1, d2, d3, value_7);
    };

    return function (value_8) {
      return field("SetZpoolProp", decoder_3, value_8);
    };
  })());
  const decodeSetZfsProp = __exports.decodeSetZfsProp = CurriedLambda((() => {
    let decoder_4;

    const ctor = function (guid, name, key, value$$1) {
      return new ZedCommand(8, [guid, name, key, value$$1]);
    };

    let d1;

    const decoder = function (value_1) {
      return string$1(value_1);
    };

    d1 = function (value_2) {
      return field("0", decoder, value_2);
    };

    let d2;

    const decoder_1 = function (value_3) {
      return string$1(value_3);
    };

    d2 = function (value_4) {
      return field("1", decoder_1, value_4);
    };

    let d3;

    const decoder_2 = function (value_5) {
      return string$1(value_5);
    };

    d3 = function (value_6) {
      return field("2", decoder_2, value_6);
    };

    let d4;

    const decoder_3 = function (value_7) {
      return string$1(value_7);
    };

    d4 = function (value_8) {
      return field("3", decoder_3, value_8);
    };

    decoder_4 = function (value_9) {
      return map4(ctor, d1, d2, d3, d4, value_9);
    };

    return function (value_10) {
      return field("SetZfsProp", decoder_4, value_10);
    };
  })());
  const decodeAddVdev = __exports.decodeAddVdev = CurriedLambda((() => {
    let decoder_1;

    const ctor = $var2 => {
      return new ZedCommand(9, $var2);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    decoder_1 = function (value_2) {
      return map$5(ctor, d1, value_2);
    };

    return function (value_3) {
      return field("AddVdev", decoder_1, value_3);
    };
  })());
  const decode$$1 = __exports.decode = CurriedLambda((() => {
    let decoder;
    const decoders = ofArray([decodeInit, decodeCreateZPool, decodeImportZPool, decodeExportZPool, decodeDestroyZpool, decodeCreateZfs, decodeDestroyZfs, decodeSetZpoolProp, decodeSetZfsProp, decodeAddVdev]);

    decoder = function (value$$1) {
      return oneOf(decoders, value$$1);
    };

    return function (value_1) {
      return field("ZedCommand", decoder, value_1);
    };
  })());
  return __exports;
}({});
class UdevCommand {
  constructor(tag, data) {
    this.tag = tag | 0;
    this.data = data;
  }

  [_Symbol.reflection]() {
    return {
      type: "IML.Types.CommandTypes.UdevCommand",
      interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
      cases: [["Add", "string"], ["Change", "string"], ["Remove", "string"]]
    };
  }

  Equals(other) {
    return this === other || this.tag === other.tag && equals$1(this.data, other.data);
  }

  CompareTo(other) {
    return compareUnions(this, other) | 0;
  }

}
setType("IML.Types.CommandTypes.UdevCommand", UdevCommand);
const UdevCommandModule = function (__exports) {
  const encode_1 = __exports.encode = function (x) {
    return function (x_1) {
      return object(ofArray([["UdevCommand", x_1]]));
    }(x.tag === 1 ? object(ofArray([["Change", string(x.data)]])) : x.tag === 2 ? object(ofArray([["Remove", string(x.data)]])) : object(ofArray([["Add", string(x.data)]])));
  };

  const decodeAdd = __exports.decodeAdd = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new UdevCommand(0, arg0);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("Add", decoder, value_1);
    };

    return function (value_2) {
      return map$5(ctor, d1, value_2);
    };
  })());
  const decodeChange = __exports.decodeChange = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new UdevCommand(1, arg0);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("Change", decoder, value_1);
    };

    return function (value_2) {
      return map$5(ctor, d1, value_2);
    };
  })());
  const decodeRemove = __exports.decodeRemove = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new UdevCommand(2, arg0);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("Remove", decoder, value_1);
    };

    return function (value_2) {
      return map$5(ctor, d1, value_2);
    };
  })());
  const decode_1 = __exports.decode = CurriedLambda((() => {
    let decoder;
    const decoders = ofArray([decodeAdd, decodeChange, decodeRemove]);

    decoder = function (value$$1) {
      return oneOf(decoders, value$$1);
    };

    return function (value_1) {
      return field("UdevCommand", decoder, value_1);
    };
  })());
  return __exports;
}({});
class MountCommand {
  constructor(tag, data) {
    this.tag = tag | 0;
    this.data = data;
  }

  [_Symbol.reflection]() {
    return {
      type: "IML.Types.CommandTypes.MountCommand",
      interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
      cases: [["AddMount", Any, Any, Any, Any], ["RemoveMount", Any, Any, Any, Any], ["ReplaceMount", Any, Any, Any, Any, Any], ["MoveMount", Any, Any, Any, Any, Any]]
    };
  }

  Equals(other) {
    return this === other || this.tag === other.tag && equals$1(this.data, other.data);
  }

  CompareTo(other) {
    return compareUnions(this, other) | 0;
  }

}
setType("IML.Types.CommandTypes.MountCommand", MountCommand);
const MountCommandModule = function (__exports) {
  const encode_2 = __exports.encode = function (x) {
    var target;
    var source;
    var opts;
    var fstype;
    var target_1;
    var source_1;
    var opts_1;
    var oldOpts;
    var fstype_1;
    var target_2;
    var source_2;
    var opts_2;
    var oldTarget;
    var fstype_2;
    var target_3;
    var source_3;
    var opts_3;
    var fstype_3;
    return function (x_1) {
      return object(ofArray([["MountCommand", x_1]]));
    }(x.tag === 1 ? (target = x.data[0], source = x.data[1], opts = x.data[3], fstype = x.data[2], object(ofArray([["RemoveMount", array([string(target), string(source), string(fstype), string(opts)])]]))) : x.tag === 2 ? (target_1 = x.data[0], source_1 = x.data[1], opts_1 = x.data[3], oldOpts = x.data[4], fstype_1 = x.data[2], object(ofArray([["ReplaceMount", array([string(target_1), string(source_1), string(fstype_1), string(opts_1), string(oldOpts)])]]))) : x.tag === 3 ? (target_2 = x.data[0], source_2 = x.data[1], opts_2 = x.data[3], oldTarget = x.data[4], fstype_2 = x.data[2], object(ofArray([["MoveMount", array([string(target_2), string(source_2), string(fstype_2), string(opts_2), string(oldTarget)])]]))) : (target_3 = x.data[0], source_3 = x.data[1], opts_3 = x.data[3], fstype_3 = x.data[2], object(ofArray([["AddMount", array([string(target_3), string(source_3), string(fstype_3), string(opts_3)])]]))));
  };

  const decodeAddMount = __exports.decodeAddMount = CurriedLambda((() => {
    let decoder_4;

    const ctor = function (target, source, fstype, opts) {
      return new MountCommand(0, [target, source, fstype, opts]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    let d4;

    const decoder_3 = function (value_6) {
      return string$1(value_6);
    };

    d4 = function (value_7) {
      return field("3", decoder_3, value_7);
    };

    decoder_4 = function (value_8) {
      return map4(ctor, d1, d2, d3, d4, value_8);
    };

    return function (value_9) {
      return field("AddMount", decoder_4, value_9);
    };
  })());
  const decodeRemoveMount = __exports.decodeRemoveMount = CurriedLambda((() => {
    let decoder_4;

    const ctor = function (target, source, fstype, opts) {
      return new MountCommand(1, [target, source, fstype, opts]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    let d4;

    const decoder_3 = function (value_6) {
      return string$1(value_6);
    };

    d4 = function (value_7) {
      return field("3", decoder_3, value_7);
    };

    decoder_4 = function (value_8) {
      return map4(ctor, d1, d2, d3, d4, value_8);
    };

    return function (value_9) {
      return field("RemoveMount", decoder_4, value_9);
    };
  })());
  const decodeReplaceMount = __exports.decodeReplaceMount = CurriedLambda((() => {
    let decoder_5;

    const ctor = function (target, source, fstype, opts, oldOpts) {
      return new MountCommand(2, [target, source, fstype, opts, oldOpts]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    let d4;

    const decoder_3 = function (value_6) {
      return string$1(value_6);
    };

    d4 = function (value_7) {
      return field("3", decoder_3, value_7);
    };

    let d5;

    const decoder_4 = function (value_8) {
      return string$1(value_8);
    };

    d5 = function (value_9) {
      return field("4", decoder_4, value_9);
    };

    decoder_5 = function (value_10) {
      return map5(ctor, d1, d2, d3, d4, d5, value_10);
    };

    return function (value_11) {
      return field("ReplaceMount", decoder_5, value_11);
    };
  })());
  const decodeMoveMount = __exports.decodeMoveMount = CurriedLambda((() => {
    let decoder_5;

    const ctor = function (target, source, fstype, opts, oldTarget) {
      return new MountCommand(3, [target, source, fstype, opts, oldTarget]);
    };

    let d1;

    const decoder = function (value$$1) {
      return string$1(value$$1);
    };

    d1 = function (value_1) {
      return field("0", decoder, value_1);
    };

    let d2;

    const decoder_1 = function (value_2) {
      return string$1(value_2);
    };

    d2 = function (value_3) {
      return field("1", decoder_1, value_3);
    };

    let d3;

    const decoder_2 = function (value_4) {
      return string$1(value_4);
    };

    d3 = function (value_5) {
      return field("2", decoder_2, value_5);
    };

    let d4;

    const decoder_3 = function (value_6) {
      return string$1(value_6);
    };

    d4 = function (value_7) {
      return field("3", decoder_3, value_7);
    };

    let d5;

    const decoder_4 = function (value_8) {
      return string$1(value_8);
    };

    d5 = function (value_9) {
      return field("4", decoder_4, value_9);
    };

    decoder_5 = function (value_10) {
      return map5(ctor, d1, d2, d3, d4, d5, value_10);
    };

    return function (value_11) {
      return field("MoveMount", decoder_5, value_11);
    };
  })());
  const decode_2 = __exports.decode = CurriedLambda((() => {
    let decoder;
    const decoders = ofArray([decodeAddMount, decodeRemoveMount, decodeReplaceMount, decodeMoveMount]);

    decoder = function (value$$1) {
      return oneOf(decoders, value$$1);
    };

    return function (value_1) {
      return field("MountCommand", decoder, value_1);
    };
  })());
  return __exports;
}({});
class Command {
  constructor(tag, data) {
    this.tag = tag | 0;
    this.data = data;
  }

  [_Symbol.reflection]() {
    return {
      type: "IML.Types.CommandTypes.Command",
      interfaces: ["FSharpUnion", "System.IEquatable", "System.IComparable"],
      cases: [["Stream"], ["ZedCommand", ZedCommand], ["UdevCommand", UdevCommand], ["MountCommand", MountCommand]]
    };
  }

  Equals(other) {
    return this === other || this.tag === other.tag && equals$1(this.data, other.data);
  }

  CompareTo(other) {
    return compareUnions(this, other) | 0;
  }

}
setType("IML.Types.CommandTypes.Command", Command);
const CommandModule = function (__exports) {
  const encode_3 = __exports.encode = function (x) {
    if (x.tag === 1) {
      return ZedCommandModule.encode(x.data);
    } else if (x.tag === 2) {
      return UdevCommandModule.encode(x.data);
    } else if (x.tag === 3) {
      return MountCommandModule.encode(x.data);
    } else {
      return string("Stream");
    }
  };

  const encoder = __exports.encoder = function (x) {
    return encode(0, encode_3(x));
  };

  const decodeMount = __exports.decodeMount = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new Command(3, arg0);
    };

    return function (value$$1) {
      return map$5(ctor, MountCommandModule.decode, value$$1);
    };
  })());
  const decodeUdev = __exports.decodeUdev = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new Command(2, arg0);
    };

    return function (value$$1) {
      return map$5(ctor, UdevCommandModule.decode, value$$1);
    };
  })());
  const decodeZed = __exports.decodeZed = CurriedLambda((() => {
    const ctor = function (arg0) {
      return new Command(1, arg0);
    };

    return function (value$$1) {
      return map$5(ctor, ZedCommandModule.decode, value$$1);
    };
  })());
  const decodeStream = __exports.decodeStream = CurriedLambda(CurriedLambda((() => {
    const cb = CurriedLambda(function (_arg1) {
      if (_arg1 === "Stream") {
        const output = new Command(0);
        return function (arg10_) {
          return succeed(output, arg10_);
        };
      } else {
        const msg = "Expected Command.Stream, got " + _arg1;
        return function (arg10__1) {
          return fail(msg, arg10__1);
        };
      }
    });
    return function (decoder, value$$1) {
      return andThen(cb, decoder, value$$1);
    };
  })())(string$1));
  const decode_3 = __exports.decode = CurriedLambda((() => {
    const decoders = ofArray([decodeStream, decodeZed, decodeUdev, decodeMount]);
    return function (value$$1) {
      return oneOf(decoders, value$$1);
    };
  })());
  const decoder = __exports.decoder = CurriedLambda($var3 => {
    var mapping;
    return (mapping = function (arg00) {
      return new Error(arg00);
    }, function (result) {
      return mapError(mapping, result);
    })(function (value$$1) {
      return decodeString(decode_3, value$$1);
    }($var3));
  });
  return __exports;
}({});

function sendData(x) {
  var objectArg;
  const opts = {};
  opts.path = "/var/run/device-scanner.sock";
  const client = net.connect(opts);
  client.end.bind(client)((objectArg = buffer.Buffer, objectArg.from.bind(objectArg))(CommandModule.encoder(x)));
}
const env = process.env;
const Udev = function (__exports) {
  const getAction = __exports.getAction = function () {
    return env.ACTION;
  };

  return __exports;
}({});
const Zpool = function (__exports) {
  const getGuid = __exports.getGuid = function () {
    return env.ZEVENT_POOL_GUID;
  };

  const getState = __exports.getState = function () {
    return env.ZEVENT_POOL_STATE_STR;
  };

  const getName = __exports.getName = function () {
    return env.ZEVENT_POOL;
  };

  return __exports;
}({});
const Zfs = function (__exports) {
  const getName_1 = __exports.getName = function () {
    return env.ZEVENT_HISTORY_DSNAME;
  };

  const getNameOption = __exports.getNameOption = function () {
    return defaultArg(env.ZEVENT_HISTORY_DSNAME, null, function (arg0) {
      return arg0;
    });
  };

  return __exports;
}({});
const Vdev = function (__exports) {
  const getGuid_1 = __exports.getGuid = function () {
    return env.ZEVENT_VDEV_GUID;
  };

  const getState_1 = __exports.getState = function () {
    return env.ZEVENT_VDEV_STATE_STR;
  };

  return __exports;
}({});
const Zed = function (__exports) {
  const getHistoryName = __exports.getHistoryName = function () {
    return env.ZEVENT_HISTORY_INTERNAL_NAME;
  };

  const getHistoryStr = __exports.getHistoryStr = function () {
    return env.ZEVENT_HISTORY_INTERNAL_STR;
  };

  return __exports;
}({});

const x = new Command(1, new ZedCommand(4, Zpool.getGuid()));
sendData(x);

exports.x = x;
